@@ -16,16 +16,7 @@ import subprocess
 import sys
 import tempfile
 import textwrap
-
-# internal modules
-from hledger_utils.utils import (
-    find_hledger_command,
-    sanitize_filename,
-    vipe,
-    two_at_a_time,
-    splitlines,
-)
-from hledger_utils.version import __version__
+from contextlib import contextmanager
 
 # external modules
 import rich
@@ -35,8 +26,30 @@ from rich.panel import Panel
 from rich.pretty import Pretty
 from rich.syntax import Syntax
 
+# internal modules
+from hledger_utils.utils import (
+    find_hledger_command,
+    sanitize_filename,
+    splitlines,
+    two_at_a_time,
+    vipe,
+)
+from hledger_utils.version import __version__
 
 console = Console(stderr=True)
+
+
+@contextmanager
+def console_status(status):
+    if os.environ.get("HLEDGER_EDIT_NOTTY") in {"yes"}:
+        logger.info(status)
+        yield
+    else:
+        with console.status(status):
+            yield
+        logger.info(status)
+
+
 logger = logging.getLogger(__name__)
 
 parser = argparse.ArgumentParser(
@@ -52,6 +65,13 @@ parser = argparse.ArgumentParser(
     # Edit all transactions you made in Europe in 2022 in your $EDITOR
     hledger edit tag:location=Europe date:2022
 
+    # Replace preamble text
+    HLEDGER_EDIT_PREAMBLE='# These are your TODOs!' hledger edit tag:TODO
+    # Prepend to preamble
+    HLEDGER_EDIT_BEFORE_PREAMBLE='# Read the comment below!!!' hledger edit tag:TODO
+    # Append to preamble
+    HLEDGER_EDIT_AFTER_PREAMBLE='# Read the comment above!!!' hledger edit tag:TODO
+
 
 📝  Specifying Your Editor
 ---------------------------
@@ -116,18 +136,15 @@ def cli(cli_args=sys.argv[1:]):
     logger.debug(f"{hledger_remaining_args = }")
     hledger_cmdparts = [args.hledger, "print"] + hledger_args
     hledger_cmdparts_with_json = hledger_cmdparts + ["-O", "json"]
+
     try:
-        if os.environ.get("HLEDGER_EDIT_NOTTY") in {"yes"}:
+        with console_status(
+            f"Running {shlex.join(hledger_cmdparts_with_json)!r}"
+        ):
             hledger_output = subprocess.check_output(
                 hledger_cmdparts_with_json
             )
-        else:
-            with console.status(
-                f"Running {shlex.join(hledger_cmdparts_with_json)!r}"
-            ):
-                hledger_output = subprocess.check_output(
-                    hledger_cmdparts_with_json
-                )
+
     except subprocess.CalledProcessError as e:
         logger.error(e)
         sys.exit(1)
@@ -207,7 +224,11 @@ def cli(cli_args=sys.argv[1:]):
     logger.debug(f"{transactionSources = }")
 
     # assemble original order from cache
-    editorContentParts = [
+    editorContentParts = []
+    if preamble := os.environ.get("HLEDGER_EDIT_BEFORE_PREAMBLE"):
+        editorContentParts.append(str(preamble))
+    if preamble := os.environ.get(
+        "HLEDGER_EDIT_PREAMBLE",
         f"""
 # 🔎  These are the results of the query:
 #
@@ -217,8 +238,11 @@ def cli(cli_args=sys.argv[1:]):
 # If you delete a whole block including the '# starts ...' and '# ends ...' comments, no changes will be applied there.
 #
 # ✅  If you are done editing, save and close the editor. Your changes will be applied to the respective file locations.
-""".strip()
-    ]
+""".strip(),
+    ):
+        editorContentParts.append(str(preamble))
+    if preamble := os.environ.get("HLEDGER_EDIT_AFTER_PREAMBLE"):
+        editorContentParts.append(str(preamble))
     for sourceFile, lineStart, lineEnd in locations:
         transactionSource = transactionSources[sourceFile][
             (lineStart, lineEnd)
@@ -347,7 +371,7 @@ def cli(cli_args=sys.argv[1:]):
             newTransactionSources[sourceFile][
                 (lineStart, lineEnd)
             ] = newContent
-            if logger.level <= logging.DEBUG:
+            if logger.getEffectiveLevel() <= logging.DEBUG:
                 console.print(
                     Panel(
                         Syntax(
@@ -403,7 +427,7 @@ def cli(cli_args=sys.argv[1:]):
         logger.debug(f"{newLines = }")
 
         # console.log(Pretty(newLines, indent_guides=True))
-        if logger.level <= logging.INFO:
+        if logger.getEffectiveLevel() <= logging.INFO:
             console.print(
                 Panel(
                     Syntax(
