@@ -48,7 +48,7 @@ def vipe(inputstr: str, prefix: str = "", suffix: str = "") -> str:
                     ]
                     + ["nano", "pico", "emacs", "vim", "vi"]
                 )
-                if shutil.which(shlex.split(editor)[0])
+                if shutil.which(next(iter(shlex.split(editor)), ""))
             ),
             None,
         )
@@ -73,7 +73,7 @@ def vipe(inputstr: str, prefix: str = "", suffix: str = "") -> str:
             os.remove(tmpfile)
         except (NameError, OSError) as error:
             logger.error(f"⚠️  Couldn't remove {tmpfile = !r}: {error = !r}")
-    return outputstr.removesuffix("\r\n").removesuffix("\n")
+    return re.sub(r"\n$", r"", re.sub(r"\r\n$", r"", outputstr))
 
 
 def two_at_a_time(iterable):
